Changelog
=========

2023.2
------

* Released on 2nd March 2023.
* Fixed project backup with unicode website URLs.

2023.1
------

* Released on 5th February 2023.
* Fixed testsuite failure.
* Added support for Python 3.11 and 3.10.
* Dropped support for Python 3.6.
* Fixed project backups schema to allow blank project website.

2022.1
------

* Released on 17th August 2022.
* Added validate_schema API.
* Added caching to schema loading.
* Added timestamp validation.
* Switched to CalVer versioning.
* Added schema for component backups.

0.8
---

* Released on 25th July 2022.
* Added schema for project backups.

0.7
---

* Released on 17th Match 2021.
* Fixed minor syntax issue in user data schema.

0.6
---

* Released on 5th Match 2021.
* Improved examples.
* Fixed license information.

0.5
---

* Released on 8th Decemeber 2020.
* Fixed validation of translation memory entries with newlines.

0.4
---

* Released on 5th August 2020.
* Added schema for user downloadable data.

0.3
---

* Released on 10th March 2020.
* Switch to more standard naming of schema files (.schema.json).

0.2
---

* Released on 10th March 2020.
* Fixed language code validation.

0.1
---

* Released on 10th March 2020.
* Initial release.
